Dinkydicom is for quick viewing of dicom files, especially for enhanced MR images that you'd like to see in mosaic format. It is not intended to be used for diagnostic purposes. At this time the patient-centered directions of the image are not displayed, and the images are not guaranteed to be in any particular orientation. Use another viewer if you need to know left from right.  

Here's a quick description of the menu options.  

Dicom folder: folder containing dicom data. If there's more than one series here, you might get odd results.  

File: Dicom instance number for the file you wish to view.  

Frame: Frame or slice you wish to view. Demosaic mode only.  

Axis: switch between axial, coronal, sagital (what number corresponds to which depends on the sequence)  

vmin, vmax: minimum and maximum intensity values for display  

Demosaic: switch between mosaic and framewise views (enhanced MR dicom only)  

Rotate: rotate the viewed image 90 degrees for each press of the button  

Show DICOM file: show contents of currently selected DICOM file as text
